from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cstate:
	"""Cstate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cstate", core, parent)

	def set(self, comp_state: bool, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:GDELay:CSTate \n
		Snippet: driver.source.iq.output.digital.bbmm.gdelay.cstate.set(comp_state = False, iqConnector = repcap.IqConnector.Default) \n
		Enables/disables group delay compensation. \n
			:param comp_state: 0| 1| OFF| ON
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')"""
		param = Conversions.bool_to_str(comp_state)
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:GDELay:CSTate {param}')

	def get(self, iqConnector=repcap.IqConnector.Default) -> bool:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:GDELay:CSTate \n
		Snippet: value: bool = driver.source.iq.output.digital.bbmm.gdelay.cstate.get(iqConnector = repcap.IqConnector.Default) \n
		Enables/disables group delay compensation. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: comp_state: 0| 1| OFF| ON"""
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:GDELay:CSTate?')
		return Conversions.str_to_bool(response)
