from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Pattern: List[str]: numeric
			- Bitcount: int: integer Range: 32 to 32"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def set(self, structure: PatternStruct, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:DATA:PATTern \n
		Snippet: driver.source.bb.evdo.user.data.pattern.set(value = [PROPERTY_STRUCT_NAME](), userIx = repcap.UserIx.Default) \n
		Sets the data pattern for the data portion of the packets sent to the user. The most significant bit (MSB) of this value
		is the MSB of the packet and the word is repeated to fill all space within the packet. \n
			:param structure: for set value, see the help for PatternStruct structure arguments.
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write_struct(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:DATA:PATTern', structure)

	def get(self, userIx=repcap.UserIx.Default) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.evdo.user.data.pattern.get(userIx = repcap.UserIx.Default) \n
		Sets the data pattern for the data portion of the packets sent to the user. The most significant bit (MSB) of this value
		is the MSB of the packet and the word is repeated to fill all space within the packet. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:DATA:PATTern?', self.__class__.PatternStruct())
