from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RvpSequence:
	"""RvpSequence commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: TwoStreams, default value after init: TwoStreams.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rvpSequence", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_twoStreams_get', 'repcap_twoStreams_set', repcap.TwoStreams.Nr1)

	def repcap_twoStreams_set(self, enum_value: repcap.TwoStreams) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TwoStreams.Default
		Default value after init: TwoStreams.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_twoStreams_get(self) -> repcap.TwoStreams:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, rvp_sequence: str, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default, twoStreams=repcap.TwoStreams.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:RVPSequence<DI> \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.rvpSequence.set(rvp_sequence = '1', baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default, twoStreams = repcap.TwoStreams.Default) \n
		The parameter is enabled for 'HARQ Simulation Mode' set to Constant NACK. Enters a sequence of Redundancy Version
		Parameters per stream. The value of the RV parameter determines the processing of the Forward Error Correction and
		Constellation Arrangement (16/64QAM modulation) , see TS 25.212 4.6.2. The sequence has a length of maximum 30 values.
		The sequence length determines the maximum number of retransmissions. New data is used after reaching the end of the
		sequence. For HS-SCCH Type 2 (less operation) , the Redundancy Version Parameter Sequence is a read-only parameter. \n
			:param rvp_sequence: string
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'RvpSequence')"""
		param = Conversions.value_to_quoted_str(rvp_sequence)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		twoStreams_cmd_val = self._base.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:RVPSequence{twoStreams_cmd_val} {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default, twoStreams=repcap.TwoStreams.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:RVPSequence<DI> \n
		Snippet: value: str = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.rvpSequence.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default, twoStreams = repcap.TwoStreams.Default) \n
		The parameter is enabled for 'HARQ Simulation Mode' set to Constant NACK. Enters a sequence of Redundancy Version
		Parameters per stream. The value of the RV parameter determines the processing of the Forward Error Correction and
		Constellation Arrangement (16/64QAM modulation) , see TS 25.212 4.6.2. The sequence has a length of maximum 30 values.
		The sequence length determines the maximum number of retransmissions. New data is used after reaching the end of the
		sequence. For HS-SCCH Type 2 (less operation) , the Redundancy Version Parameter Sequence is a read-only parameter. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'RvpSequence')
			:return: rvp_sequence: string"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		twoStreams_cmd_val = self._base.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:RVPSequence{twoStreams_cmd_val}?')
		return trim_str_response(response)

	def clone(self) -> 'RvpSequence':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RvpSequence(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
