from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConSubFrames:
	"""ConSubFrames commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("conSubFrames", core, parent)

	@property
	def xpucch(self):
		"""xpucch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpucch'):
			from .Xpucch import Xpucch
			self._xpucch = Xpucch(self._core, self._base)
		return self._xpucch

	@property
	def xpusch(self):
		"""xpusch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpusch'):
			from .Xpusch import Xpusch
			self._xpusch = Xpusch(self._core, self._base)
		return self._xpusch

	def clone(self) -> 'ConSubFrames':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ConSubFrames(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
