from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, usch_scram_state: bool, userNull=repcap.UserNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:USCH:SCRambling:STATe \n
		Snippet: driver.source.bb.nr5G.ubwp.user.usch.scrambling.state.set(usch_scram_state = False, userNull = repcap.UserNull.Default) \n
		Turns PUSCH scrambling on and off. \n
			:param usch_scram_state: 0| 1| OFF| ON
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')"""
		param = Conversions.bool_to_str(usch_scram_state)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:USCH:SCRambling:STATe {param}')

	def get(self, userNull=repcap.UserNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:USCH:SCRambling:STATe \n
		Snippet: value: bool = driver.source.bb.nr5G.ubwp.user.usch.scrambling.state.get(userNull = repcap.UserNull.Default) \n
		Turns PUSCH scrambling on and off. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:return: usch_scram_state: No help available"""
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:USCH:SCRambling:STATe?')
		return Conversions.str_to_bool(response)
