from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LdMrs:
	"""LdMrs commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ldMrs", core, parent)

	def set(self, up_pts_less_dmrs: bool, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:UPPTs:LDMRs \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.pusch.uppts.ldMrs.set(up_pts_less_dmrs = False, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		If enabled, the number of used demodulation reference signals (DMRS) is reduced. \n
			:param up_pts_less_dmrs: 0| 1| OFF| ON
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.bool_to_str(up_pts_less_dmrs)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:UPPTs:LDMRs {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:UPPTs:LDMRs \n
		Snippet: value: bool = driver.source.bb.eutra.uplink.ue.cell.pusch.uppts.ldMrs.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		If enabled, the number of used demodulation reference signals (DMRS) is reduced. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: up_pts_less_dmrs: 0| 1| OFF| ON"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:UPPTs:LDMRs?')
		return Conversions.str_to_bool(response)
