from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPy:
	"""ListPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("listPy", core, parent)

	def get_state(self) -> bool:
		"""SCPI: OUTPut<HW>:BLANk:LIST:STATe \n
		Snippet: value: bool = driver.output.blank.listPy.get_state() \n
		Activates RF output blanking. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:BLANk:LIST:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: OUTPut<HW>:BLANk:LIST:STATe \n
		Snippet: driver.output.blank.listPy.set_state(state = False) \n
		Activates RF output blanking. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'OUTPut<HwInstance>:BLANk:LIST:STATe {param}')
